@@ -2,15 +2,16 @@
 # and also by Makefile.PL, so this file should not depend on any
 # nonstandard libraries.
 #
-# $Id: AskTerm.pm,v 1.10 2004/04/04 08:31:11 epaepa Exp $
+# $Id: AskTerm.pm,v 1.14 2004/05/23 16:30:01 epaepa Exp $
 #
 package XMLTV::AskTerm;
 use strict;
 use base 'Exporter';
 our @EXPORT = qw(ask
-                 askQuestion
-                 askBooleanQuestion
-                 askManyBooleanQuestions
+		 ask_password
+                 ask_question               askQuestion
+                 ask_boolean_question       askBooleanQuestion
+                 ask_many_boolean_questions askManyBooleanQuestions
                  say
                 );
 use Carp qw(croak carp);
@@ -29,9 +30,10 @@ BEGIN {
 }
 
 sub ask( $ );
-sub askQuestion( $$@ );
-sub askBooleanQuestion( $$ );
-sub askManyBooleanQuestions( $@ );
+sub ask_password( $ );
+sub ask_question( $$@ );              sub askQuestion( $$@ );
+sub ask_boolean_question( $$ );       sub askBooleanQuestion( $$ );
+sub ask_many_boolean_questions( $@ ); sub askManyBooleanQuestions( $@ );
 sub say( $ );
 
 sub ask( $ )
@@ -43,6 +45,10 @@ sub ask( $ )
     my $r = <STDIN>;
     for ($r) {
 	return undef if not defined;
+
+	# Handle backspace, for broken terminals that don't.
+	s/.\x08//g;
+
 	s/^\s+//;
 	s/\s+$//;
 	return $_;
@@ -75,7 +81,7 @@ sub match( $@ ) {
 #
 # Returns one of the choices, or undef if input could not be read.
 #
-sub askQuestion( $$@ )
+sub ask_question( $$@ )
 {
     my $question=shift(@_); die if not defined $question;
     chomp $question;
@@ -93,7 +99,15 @@ sub askQuestion( $$@ )
 
     # Check no duplicates (required for later processing, maybe).
     my %seen;
-    foreach (@options) { die "duplicate option $_" if $seen{$_}++ }
+    my @options_new;
+    foreach (@options) {
+	if ($seen{$_}++) {
+	    carp "removing duplicate option $_";
+	    next;
+	}
+	push @options_new, $_;
+    }
+    @options = @options_new;
 
     my $options_size = length("@options");
     t "size of options: $options_size";
@@ -160,6 +174,7 @@ sub askQuestion( $$@ )
 	}
     }
 }
+sub askQuestion( $$@ ) { &ask_question }
 
 # Ask a yes/no question.
 #
@@ -168,7 +183,7 @@ sub askQuestion( $$@ )
 #
 # Returns true or false, or undef if input could not be read.
 #
-sub askBooleanQuestion( $$ )
+sub ask_boolean_question( $$ )
 {
     my ($text, $default) = @_;
     my $r = askQuestion($text, ($default ? 'yes' : 'no'), 'yes', 'no');
@@ -177,6 +192,7 @@ sub askBooleanQuestion( $$ )
     return 0 if $r eq 'no';
     die;
 }
+sub askBooleanQuestion( $$ ) { &ask_boolean_question }
 
 # Ask yes/no questions with option 'default to all'.
 #
@@ -186,7 +202,7 @@ sub askBooleanQuestion( $$ )
 # Returns: lots of booleans, one for each question.  If input cannot
 # be read, then a partial list is returned.
 #
-sub askManyBooleanQuestions( $@ )
+sub ask_many_boolean_questions( $@ )
 {
     my $default = shift;
 
@@ -221,6 +237,7 @@ sub askManyBooleanQuestions( $@ )
     }
     return @r;
 }
+sub askManyBooleanQuestions( $@ ) { &ask_many_boolean_questions }
 
 sub say( $ )
 {
@@ -229,5 +246,22 @@ sub say( $ )
     print STDERR "$question\n";
 }
 
+sub ask_password( $ ) {
+    my $prompt = shift;
+    chomp $prompt;
+    $prompt .= ' ' if $prompt !~ /\s$/;
+    require Term::ReadKey;
+    Term::ReadKey::ReadMode('noecho');
+    print STDERR $prompt;
+    my $r = <STDIN>;
+    print STDERR "\n";
+    Term::ReadKey::ReadMode('normal');
+    for ($r) {
+	return undef if not defined;
+	s/^\s+//;
+	s/\s+$//;
+	return $_;
+    }
+}
 
 1;
